@@ -53,7 +53,7 @@
 #  \item{skip}{If @TRUE and the output file already exists,
 #    the output file is returned as is.}
 #  \item{overwrite}{If @TRUE and the output file already exists,
-#    the file is silently overwritting, otherwise an exception is
+#    the file is silently overwritten, otherwise an exception is
 #    thrown (unless \code{skip} is @TRUE).}
 #  \item{remove}{If @TRUE, the input file is removed afterward,
 #    otherwise not.}
@@ -122,26 +122,26 @@
 setMethodS3("compressFile", "default", function(filename, destname=sprintf("%s.%s", filename, ext), ext, FUN, temporary=FALSE, skip=FALSE, overwrite=FALSE, remove=TRUE, BFR.SIZE=1e7, ...) {
   # Argument 'filename':
   if (!file.exists(filename)) {
-    stop("No such file: ", filename);
+    stop("No such file: ", filename)
   }
 
   # Argument 'ext':
-  ext <- as.character(ext);
+  ext <- as.character(ext)
 
   # Argument 'FUN':
   if (!is.function(FUN)) {
-    stop(sprintf("Argument 'FUN' is not a function: %s", mode(FUN)));
+    stop(sprintf("Argument 'FUN' is not a function: %s", mode(FUN)))
   }
 
   # Argument 'temporary':
   if (temporary) {
-    destname <- file.path(tempdir(), basename(destname));
+    destname <- file.path(tempdir(), basename(destname))
   }
-  attr(destname, "temporary") <- temporary;
+  attr(destname, "temporary") <- temporary
 
   # Argument 'filename' & 'destname':
   if (filename == destname) {
-    stop(sprintf("Argument 'filename' and 'destname' are identical: %s", filename));
+    stop(sprintf("Argument 'filename' and 'destname' are identical: %s", filename))
   }
 
   # Already done?
@@ -159,12 +159,12 @@ setMethodS3("compressFile", "default", function(filename, destname=sprintf("%s.%
   destnameT <- pushTemporaryFile(destname)
 
   # Create output directory, iff missing
-  destpath <- dirname(destnameT);
-  if (!isDirectory(destpath)) mkdirs(destpath, mustWork=TRUE);
+  destpath <- dirname(destnameT)
+  if (!isDirectory(destpath)) mkdirs(destpath, mustWork=TRUE)
 
   # Setup input and output connections
-  inn <- file(filename, open="rb");
-  on.exit(if (!is.null(inn)) close(inn));
+  inn <- file(filename, open="rb")
+  on.exit(if (!is.null(inn)) close(inn))
 
   outComplete <- FALSE
   out <- FUN(destnameT, open="wb", ...)
@@ -179,11 +179,11 @@ setMethodS3("compressFile", "default", function(filename, destname=sprintf("%s.%
   repeat {
     bfr <- readBin(inn, what=raw(0L), size=1L, n=BFR.SIZE)
     n <- length(bfr)
-    if (n == 0L) break;
+    if (n == 0L) break
     nbytes <- nbytes + n
     writeBin(bfr, con=out, size=1L)
     bfr <- NULL  # Not needed anymore
-  };
+  }
   outComplete <- TRUE
   close(out)
   out <- NULL
@@ -196,38 +196,38 @@ setMethodS3("compressFile", "default", function(filename, destname=sprintf("%s.%
 
   # Cleanup
   if (remove) {
-    close(inn);
-    inn <- NULL;
-    file.remove(filename);
+    close(inn)
+    inn <- NULL
+    file.remove(filename)
   }
 
-  invisible(destname);
+  invisible(destname)
 }) # compressFile()
 
 
 setMethodS3("decompressFile", "default", function(filename, destname=gsub(sprintf("[.]%s$", ext), "", filename, ignore.case=TRUE), ext, FUN, temporary=FALSE, skip=FALSE, overwrite=FALSE, remove=TRUE, BFR.SIZE=1e7, ...) {
   # Argument 'filename':
   if (!file.exists(filename)) {
-    stop("No such file: ", filename);
+    stop("No such file: ", filename)
   }
 
   # Argument 'ext':
-  ext <- as.character(ext);
+  ext <- as.character(ext)
 
   # Argument 'FUN':
   if (!is.function(FUN)) {
-    stop(sprintf("Argument 'FUN' is not a function: %s", mode(FUN)));
+    stop(sprintf("Argument 'FUN' is not a function: %s", mode(FUN)))
   }
 
   # Argument 'temporary':
   if (temporary) {
-    destname <- file.path(tempdir(), basename(destname));
+    destname <- file.path(tempdir(), basename(destname))
   }
-  attr(destname, "temporary") <- temporary;
+  attr(destname, "temporary") <- temporary
 
   # Argument 'filename' & 'destname':
   if (filename == destname) {
-    stop(sprintf("Argument 'filename' and 'destname' are identical: %s", filename));
+    stop(sprintf("Argument 'filename' and 'destname' are identical: %s", filename))
   }
 
   # Already done?
@@ -245,12 +245,12 @@ setMethodS3("decompressFile", "default", function(filename, destname=gsub(sprint
   destnameT <- pushTemporaryFile(destname)
 
   # Create output directory, iff missing
-  destpath <- dirname(destname);
-  if (!isDirectory(destpath)) mkdirs(destpath, mustWork=TRUE);
+  destpath <- dirname(destname)
+  if (!isDirectory(destpath)) mkdirs(destpath, mustWork=TRUE)
 
   # Setup input and output connections
-  inn <- FUN(filename, open="rb");
-  on.exit(if (!is.null(inn)) close(inn));
+  inn <- FUN(filename, open="rb")
+  on.exit(if (!is.null(inn)) close(inn))
 
   outComplete <- FALSE
   out <- file(destnameT, open="wb", ...)
@@ -265,11 +265,11 @@ setMethodS3("decompressFile", "default", function(filename, destname=gsub(sprint
   repeat {
     bfr <- readBin(inn, what=raw(0L), size=1L, n=BFR.SIZE)
     n <- length(bfr)
-    if (n == 0L) break;
+    if (n == 0L) break
     nbytes <- nbytes + n
     writeBin(bfr, con=out, size=1L)
     bfr <- NULL  # Not needed anymore
-  };
+  }
   outComplete <- TRUE
   close(out)
   out <- NULL
@@ -282,12 +282,12 @@ setMethodS3("decompressFile", "default", function(filename, destname=gsub(sprint
 
   # Cleanup
   if (remove) {
-    close(inn);
-    inn <- NULL;
-    file.remove(filename);
+    close(inn)
+    inn <- NULL
+    file.remove(filename)
   }
 
-  invisible(destname);
+  invisible(destname)
 }) # decompressFile()
 
 
@@ -358,49 +358,3 @@ setMethodS3("isGzipped", "default", function(..., ext="gz", fileClass="gzfile")
 ## setMethodS3("isXzipped", "default", function(..., ext="xz", fileClass="xzfile") {
 ##   isCompressedFile(..., ext=ext, fileClass=fileClass)
 ## })
-
-
-############################################################################
-# HISTORY:
-# 2015-02-01
-# o Added compressFile(), decompressFile() and isCompressedFile() methods,
-#   which gzip()/gunzip() and the new bzip2()/bunzip2() now use.
-#   Thanks to Peter Hickey for pushing for this.
-# 2013-07-27
-# o Added argument 'skip' to gzip() and gunzip().
-# o BUG FIX: gunzip() would ignore argument 'overwrite'.
-# 2013-06-27
-# o Added argument 'temporary' to gzip() and gunzip().
-# o Now gzip() passes '...' to gzfile().
-# o UPDATE: Now gzip()/gunzip() returns the output file (was number of
-#   output bytes processed which are now returned as an attribute).
-# 2013-06-26
-# o Added isGzipped() for testing whether a file is gzipped or not.
-# 2012-11-04
-# o Now bunzip2() creates the directory of destination pathname
-#   'destfile', iff missing.
-# 2012-11-01
-# o Now gzip()/gunzip() creates the directory of destination pathname
-#   'destfile', iff missing.
-# 2008-11-03
-# o Now gzip() and gunzip() removes the partially written output file if
-#   the process is interrupted.
-# 2008-05-15
-# o Added gzip().
-# 2007-08-14
-# o Added bunzip2() from gunzip().
-# o Increased the BFR.SIZE 10 times.
-# o Added argument 'remove'.
-# o Updated the regular expression for generating the output filename.
-# o Now the data is read as a raw buffer (and not as integers anymore).
-# 2005-02-20
-# o Now using setMethodS3() and added '...' to please R CMD check.
-# 2004-02-12
-# o Made into a default function.
-# 2003-12-31
-# o Copied from the com.braju.sma package and made independent of R.oo.
-# 2003-10-29
-# o BUG FIX: The 2nd on.exit() in gunzip() was overwriting the first one
-#   with the result that the open input gzfile() connection was never
-#   closed. We ran out of connections after a while.
-############################################################################
