@@ -5,19 +5,19 @@ library("R.utils")
 y <- c(a=1, b=2, c=3)
 print(y)
 x <- insert(y, ats=2:length(y))
-Ex <- c(y[1], NA, y[2], NA, y[3])
+Ex <- c(y[1], NA_real_, y[2], NA_real_, y[3])
 print(x)
 stopifnot(identical(x,Ex))
 
 # Insert at first position
 y <- c(a=1, b=2, c=3)
 print(y)
-x <- insert(y, ats=1, values=rep(NA,2))
-Ex <- c(NA,NA,y)
+x <- insert(y, ats=1, values=rep(NA_real_, 2))
+Ex <- c(NA_real_,NA_real_,y)
 print(x)
 stopifnot(identical(x,Ex))
 
-x <- insert(y, ats=1, values=rep(NA,2), useNames=FALSE)
+x <- insert(y, ats=1, values=rep(NA_real_,2), useNames=FALSE)
 print(x)
 
 # Insert at last position (names of 'values' are ignored
